import getState from './getState';
import sendApiCall from './sendApiCall';

/**
 * This method deletes the specified user's account from SAP Customer Data Cloud's database.
 * This method call can only be made as a secured server request.
 * @see https://help.sap.com/docs/SAP_CUSTOMER_DATA_CLOUD/8b8d6fffe113457094a17701f63e3d6a/4133a29470b21014bbc5a10ce4041860.html?locale=en-US.
 */
export default function ({
  UID,
  ...params
} = {}) {
  return new Promise(async (resolve, reject) => {
    try {
      const state = await getState();
      const response = await sendApiCall('accounts.deleteAccount', {
        UID: UID || state.UID,
        ...(params && params)
      });
      resolve(response);
    } catch (e) {
      reject(e);
    }
  });
}
//# sourceMappingURL=deleteAccount.js.map