import { NativeModules } from 'react-native';
const {
  GigyaSdk
} = NativeModules;
import getState from './getState';
import isGigyaError from './isGigyaError';
import { setState } from '../internals/state';
import formatParams from '../internals/formatParams';
import handleSdkCall from '../internals/handleSdkCall';
import clearErrorState from '../internals/clearErrorState';
import saveAuthenticationAttempt from '../internals/saveAuthenticationAttempt';
export default function (provider, params) {
  return new Promise(async (resolve, reject) => {
    try {
      var _state$regToken;

      const state = await getState();
      const {
        regToken,
        ...rest
      } = params || {
        regToken: (_state$regToken = state.regToken) === null || _state$regToken === void 0 ? void 0 : _state$regToken.value
      };
      const response = await handleSdkCall(GigyaSdk.socialLogin(provider, formatParams({
        regToken,
        loginMode: 'link',
        ...(rest && rest)
      })));
      await setState({
        UID: response.UID
      });

      try {
        await clearErrorState();
      } catch (err) {}

      resolve(response);
    } catch (e) {
      if (await isGigyaError(e)) {
        try {
          await saveAuthenticationAttempt(provider, e);
        } catch (err) {
          return reject(err);
        }
      }

      reject(e);
    }
  });
}
//# sourceMappingURL=linkToSocialProvider.js.map