import { decode as atob } from 'base-64';
import { GigyaSdkErrorCodes, GigyaSdkErrors } from '../types';
export default function (gigyaSdkError) {
  let {
    code,
    message,
    name,
    stack
  } = gigyaSdkError;
  let error = {
    type: GigyaSdkErrors.UndefinedError,
    payload: null,
    ...(message && {
      message
    }),
    ...(stack && {
      stack
    }),
    ...(code && {
      code
    }),
    ...(name && {
      name
    })
  };

  if (error.code && error.message) {
    var _error$payload;

    try {
      let payload = JSON.parse(gigyaSdkError.message);

      if (payload.requestData) {
        payload = JSON.parse(atob(payload.requestData));
      }

      if (payload.accountInfo && typeof payload.accountInfo === 'string') {
        payload.accountInfo = JSON.parse(payload.accountInfo);
      }

      error.payload = payload;
    } catch (e) {}

    error.type = GigyaSdkErrors[gigyaSdkError.code];
    const errorTypeIndex = Object.values(GigyaSdkErrorCodes).indexOf(error === null || error === void 0 ? void 0 : (_error$payload = error.payload) === null || _error$payload === void 0 ? void 0 : _error$payload.errorCode);

    if (errorTypeIndex !== -1) {
      const type = Object.keys(GigyaSdkErrorCodes)[errorTypeIndex];
      error.type = GigyaSdkErrors[type];
    }
  }

  return error;
}
//# sourceMappingURL=formatError.js.map